/*
 * Copyright (c) 1998-2006 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.collections;

import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * An {@link Iterator} that iterates over an array.
 * 
 * @author Torgil
 * 
 * @since 1.2
 *
 */
public class ArrayIterator<T> implements Iterator<T> {

    private final T[]   m_items;
    private final int   m_length;
    private int         m_currentIndex;
    
    /**
     * Creates an iterator over the specified array.
     * 
     * @param items
     *            the array to iterate over.
     * @throws NullPointerException
     *             if <code>items</code> is null.
     */
    public ArrayIterator(T[] items) {
        m_items = items;
        m_length = items.length;
        m_currentIndex = 0;
    }
    
    public boolean hasNext() {
        return (m_currentIndex < m_length);
    }

    public T next() {
        if (!hasNext()) {
            throw new NoSuchElementException();
        }
        return m_items[m_currentIndex++];
    }

    /**
     * Not supported.
     *  
     * @throws UnsupportedOperationException
     *             always
     */
    public void remove() {
        throw new UnsupportedOperationException();
    }
}
