/*
 * Copyright (c) 1998-2006 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.collections;

import java.util.Arrays;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Set;

/**
 * Class with utility methods for <tt>java.util.Set</tt>s.
 * 
 * @author Torgil
 * @since 1.1
 *
 */
public final class KongaSetUtils {

    private KongaSetUtils() {
        throw new UnsupportedOperationException();
    }
    
    /**
     * Creates and returns a set containing the elements in the specified
     * enumeration.
     * 
     * @throws NullPointerException
     *             if <tt>en</tt> is null.
     */
    public static <T> Set<T> asSet(Enumeration<T> en) {
        Set<T> set = new HashSet<T>();
        while (en.hasMoreElements()) {
            set.add(en.nextElement());
        }
        return set;
    }
    
    /**
     * Converts an array into a Set.
     * 
     * @param array
     * @return a <code>Set</code> consisting of all unique elements in
     *         <code>array</code>.
     * @throws NullPointerException
     *             if <code>array</code> is null.
     * @since 1.2
     */
    public static <T> Set<T> asSet(T[] array) {
        return new HashSet<T>(Arrays.asList(array));
    }
    
    /**
     * Creates a <code>Set</code> containing one single item.
     *
     * @since 1.2
     */
    public static <T> Set<T> asSet(T item) {
        Set<T> set = new HashSet<T>();
        set.add(item);
        return set;
    }
}
