/*
 * Copyright (c) 1998-2006 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.xml;

/**
 * An <code>IExpandedName</code> is a pair consisting of a namespace URI and a
 * local name. It represents the entity called "expanded name" in the WC3
 * document "Namespaces in XML 1.0":
 * <p>
 * http://www.w3.org/TR/xml-names/#concepts
 * 
 * @author Torgil
 * 
 * @since 1.2
 * 
 */
public interface IExpandedName {

    /**
     * Returns the namespace URI of this expanded name. An
     * <code>IExpandedName</code> instance representing the name
     * <code>"http://www.jitterbit.com/xml:Root"</code> returns the string
     * <code>"http://www.jitterbit.com/xml"</code> from this method.
     * 
     * @return a String holding the namespace URI of this name. This method
     *         never returns <code>null</code>; an empty string is returned
     *         if the name does not belong to a namespace.
     */
    public String getNamespace();
    
    /**
     * Returns the local part of this expanded name. An
     * <code>IExpandedName</code> instance representing the name
     * <code>"http://www.jitterbit.com/xml:Root"</code> returns the string
     * <code>"Root"</code> from this method.
     * 
     * @return a String holding the local part of this name. This method should
     *         never returns <code>null</code> or an empty String.
     */
    public String getLocalName();
 
    /**
     * An <code>IExpandedName</code> is equal to another <code>Object</code>
     * if and only if that object is an <code>IExpandedName</code>, and the
     * namespace URI and local part of the two names are equal.
     * 
     */
    public boolean equals(Object o);
    
    /**
     * Returns a string with the following format:
     * 
     * <pre>
     *    [getNamespace():]getLocalName()
     * </pre>
     * 
     * The namespace part is excluded if this name has an empty namespace URI.
     * 
     */
    public String toString();
}
