/*
 * Copyright (c) 1998-2005 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.xml.sax;

import org.xml.sax.Attributes;

/**
 * Interface that defines a simple SaxParser.
 * 
 * @see org.jitterbit.util.xml.sax.AbstractKongaSaxParser
 * 
 * @author Torgil
 *
 */
public interface IKongaSaxParser {

    /**
     * Retrieves the value of the current element.
     * @return  the value of the current element.
     */
    public abstract String  getCurrentElementValue();
    
    /**
     * Retrieves the local name of the current element.
     * @return  the current element's local name.
     */
    public abstract String getCurrentLocalName();
    
    /**
     * Retrieves the namespace URI of the current element.
     * @return  the current element's namespace URI.
     */
    public abstract String getCurrentURI();
    
    /**
     * Retrieves the QName of the current element.
     * @return  the current element's QName.
     */
    public abstract String getCurrentQName();
    
    /**
     * Retrieves the attributes of the current element.
     * @return  an <tt>Attributes</tt> object holding the attributes
     *          of the element that is currently parsed.
     */
    public abstract Attributes getCurrentAttributes();
    
    /**
     * Retrieves the <tt>StartElementHandler</tt> that has been
     * registered to handle elements with the specified properties.
     * @param uri   the namespace URI for the element in which the
     *              handler has registered interest.
     * @param localName the local name of the element in which the
     *                  handler has registered interest.
     * @param qName the QName of the element in which the handler has
     *                  registered interest.
     * @return  a <tt>StartElementHandler</tt> that will be notified when
     *          the SAX parser starts to process an element with the specified 
     *          properties. 
     */
    public abstract IStartElementHandler getStartElementHandler(String uri, 
                                                               String localName, 
                                                               String qName);
    
    /**
     * Retrieves the <tt>EndElementHandler</tt> that has been
     * registered to handle elements with the specified properties.
     * @param uri   the namespace URI for the element in which the
     *              handler has registered interest.
     * @param localName the local name of the element in which the
     *                  handler has registered interest.
     * @param qName the QName of the element in which the handler has
     *                  registered interest.
     * @return  a <tt>EndElementHandler</tt> that will be notified when
     *          the SAX parser ends the processing of an element with the 
     *          specified properties. 
     */
    public abstract IEndElementHandler getEndElementHandler(String uri, 
                                                            String localName, 
                                                            String qName);
    
}
